@@ -26,6 +26,9 @@ from iw.releaser import base
 re_version = re.compile(r"""^version\s*=\s*(?:"|')(.*?)(?:"|')""",
                         re.MULTILINE|re.DOTALL)  
 
+re_name = re.compile(r"""name\s*=\s*(?:"|')(.*?)(?:"|')""",
+                     re.MULTILINE|re.DOTALL)  
+
 def _get_setup():
     """returns setup content"""
     setup_py = os.path.join(os.getcwd(), 'setup.py')
@@ -38,6 +41,14 @@ def get_version():
         return None
     return version[0]
 
+def get_name():
+    """extract the name of the current package"""
+    name = re_name.findall(_get_setup())
+    if len(name) == 0:
+        return None
+    return name[0]
+
+
 def raise_version(version):
     """raises the version"""
     new_setup = re_version.sub("version = '%s'" % version, _get_setup())
@@ -154,20 +165,15 @@ def _checkout_tag():
 
 def _run_setup(*args):
     old_args = sys.argv
-    sys.argv = [sys.argv[0] + 'setup.py'] + list(args)
+    sys.argv = [sys.argv[0]] + list(args)
     __import__('setup')
     del sys.modules['setup']
     sys.argv = old_args
 
-def pypi_upload(interactive=False):
+def pypi_upload(commands):
     """upload into pypi"""
     _checkout_tag()
-    if not interactive:
-        res = 'y'
-    else:
-        res = raw_input('Do you want to upload to the private repo ? (Y/n):')
-        res = res.lower().strip()
-    if res == 'y':
-        _run_setup('mregister', 'sdist', 'bdist_egg', 'mupload', '-r',
-                   'ingeniweb-private')
+    for command in commands:
+        base.display('Running "%s"' % command)
+        _run_setup(*command.split())
 
